@@ -1,6 +1,5 @@
 from typing import Callable, Generic, Sequence, TypeVar, Union
-from graia.application.message.elements.internal import InternalElement
-from graia.application.message import ExternalElement
+from graia.application.message.elements import InternalElement, ExternalElement
 from graia.broadcast.entities.decorater import Decorater
 from graia.broadcast.interfaces.decorater import DecoraterInterface
 from graia.application.entry import MessageChain
@@ -59,4 +58,4 @@ class Components(Decorater, Generic[T]):
                 selected.append(value)
                 matched_times += 1
 
-        return MessageChain.create(selected[self._skip_times:])
\ No newline at end of file
+        return MessageChain.create(selected[self._skip_times:])
